/*
  LiquidCrystal Library - Hello World
 
 Demonstrates the use a 16x2 LCD display.  The LiquidCrystal
 library works with all LCD displays that are compatible with the 
 Hitachi HD44780 driver. There are many of them out there, and you
 can usually tell them by the 16-pin interface.
 
 This sketch prints "Hello World!" to the LCD
 and shows the time.
 
  The circuit:
 * LCD RS pin to digital pin 12
 * LCD RW pin to digital pin 10
 * LCD Enable pin to digital pin 11
 * LCD D4 pin to digital pin 5
 * LCD D5 pin to digital pin 4
 * LCD D6 pin to digital pin 3
 * LCD D7 pin to digital pin 2
 * 10K resistor:
 * ends to +5V and ground
 * wiper to LCD VO pin (pin 3)
 
 Library originally added 18 Apr 2008
 by David A. Mellis
 library modified 5 Jul 2009
 by Limor Fried (http://www.ladyada.net)
 example added 9 Jul 2009
 by Tom Igoe
 modified 25 July 2009
 by David A. Mellis
 modified 25 May 2010
 by Ilya V. Danilov http://mk90.ru/

 */

// include the library code:
#include <LiquidCrystal.h>

// initialize the library with the numbers of the interface pins
LiquidCrystal lcd(4, 5, 10, 11, 12, 13);

void setup() {
  // set up the LCD's number of rows and columns: 
  lcd.begin(16, 2);
  // Print a message to the LCD.
  LCDPrint(0,0,"Привет!");
}

void loop() {
  // set the cursor to column 0, line 1
  // (note: line 1 is the second row, since counting begins with 0):
  lcd.setCursor(0, 1);
  // print the number of seconds since reset:
  lcd.print(millis()/300);
  lcd.setCursor(5, 1);
  lcd.print(char(millis()/300));
}

void LCDPrint(int x, int y, String sz)
{
  lcd.setCursor(x, y);
  bool TwoByte = false;
  bool DoNotPrintNext = false;
  for (int i=0;i< sz.length() ;i++)
  {
    char ch;
    if (byte(sz[i]) == 208 || byte(sz[i]) == 209) {
      TwoByte = true;
    } else {
      TwoByte = false;
    }
    if (TwoByte == true)
    {
      if (byte(sz[i]) == 209)
      {
        switch (byte(sz[i+1])) 
        {
          case 145: // Ё
            ch = 0xA2;
            break;
          case 128: // Р
            ch = 0x70;
            break;
          case 129: // С
            ch = 0x63;
            break;
          case 130: // Т
            ch = 0xBF;
            break;
          case 131: // У
            ch = 0x79;
            break;
          case 132: // Ф
            ch = 0xE4;
            break;
          case 133: // Х
            ch = 0x78;
            break;
          case 134: // Ц
            ch = 0xE5;
            break;
          case 135: // Ч
            ch = 0xC0;
            break;
          case 136: // Ш
            ch = 0xC1;
            break;
          case 137: // Щ
            ch = 0xE6;
            break;
          case 138: // Ъ
            ch = 0xC2;
            break;
          case 139: // Ы
            ch = 0xC3;
            break;
          case 140: // Ь
            ch = 0xC4;
            break;
          case 141: // Э
            ch = 0xC5;
            break;
          case 142: // Ю
            ch = 0xC6;
            break;
          case 143: // Я
            ch = 0xC7;
            break; 
          default: 
            ch = sz[i+1];
            break;
        }
      } 
      else if (byte(sz[i]) == 208) 
      {
        switch (byte(sz[i+1])) 
        {
          case 144: // А
            ch = 0x41;
            break;
          case 145: // Б
            ch = 0xA0;
            break;
          case 146: // В
            ch = 0x42;
            break;
          case 147: // Г
            ch = 0xA1;
            break;
          case 148: // Д
            ch = 0xE0;
            break;
          case 149: // Е
            ch = 0x45;
            break;
          case 129: // Ё
            ch = 0xA2;
            break;
          case 150: // Ж
            ch = 0xA3;
            break;
          case 151: // З
            ch = 0xA4;
            break;
          case 152: // И
            ch = 0xA5;
            break;
          case 153: // Й
            ch = 0xA6;
            break;
          case 154: // К
            ch = 0x4B;
            break;
          case 155: // Л
            ch = 0xA7;
            break;
          case 156: // М
            ch = 0x4D;
            break;
          case 157: // Н
            ch = 0x48;
            break;
          case 158: // О
            ch = 0x4F;
            break;
          case 159: // П
            ch = 0xA8;
            break;
          case 160: // Р
            ch = 0x50;
            break;
          case 161: // С
            ch = 0x43;
            break;
          case 162: // Т
            ch = 0x54;
            break;
          case 163: // У
            ch = 0xA9;
            break;
          case 164: // Ф
            ch = 0xAA;
            break;
          case 165: // Х
            ch = 0x58;
            break;
          case 166: // Ц
            ch = 0xE1;
            break;
          case 167: // Ч
            ch = 0xAB;
            break;
          case 168: // Ш
            ch = 0xAC;
            break;
          case 169: // Щ
            ch = 0xE2;
            break;
          case 170: // Ъ
            ch = 0xAD;
            break;
          case 171: // Ы
            ch = 0xAE;
            break;
          case 172: // Ь
            ch = 0x08;
            break;
          case 173: // Э
            ch = 0xAF;
            break;
          case 174: // Ю
            ch = 0xB0;
            break;
          case 175: // Я
            ch = 0xB1;
            break;
  
  /* ----------------------------*/
          case 176: // А
            ch = 0x61;
            break;
          case 177: // Б
            ch = 0xB2;
            break;
          case 178: // В
            ch = 0xB3;
            break;
          case 179: // Г
            ch = 0xB4;
            break;
          case 180: // Д
            ch = 0xE3;
            break;
          case 181: // Е
            ch = 0x65;
            break;
          case 182: // Ж
            ch = 0xB6;
            break;
          case 183: // З
            ch = 0xB7;
            break;
          case 184: // И
            ch = 0xB8;
            break;
          case 185: // Й
            ch = 0xB9;
            break;
          case 186: // К
            ch = 0xBA;
            break;
          case 187: // Л
            ch = 0xBB;
            break;
          case 188: // М
            ch = 0xBC;
            break;
          case 189: // Н
            ch = 0xBD;
            break;
          case 190: // О
            ch = 0x6F;
            break;
          case 191: // П
            ch = 0xBE;
            break;
          default: 
            ch = sz[i+1];
          break;
        }
      } 
      else 
      {
        ch = sz[i+1];
      }
      lcd.print(ch);
      DoNotPrintNext = true;
    } else {
      if (!DoNotPrintNext)
        lcd.print(sz[i]);
      DoNotPrintNext = false;
    }
    //Serial.println(byte(sz[i]));
  }
}
